from distutils.core import setup

setup(
    name='bleson',
    version='0.0.1',
    packages=['bleson'],
    url='https://github.com/TheCellule/python-bleson',
    license='MIT',
    author='TheCellule',
    author_email='thecellule@gmail.com',
    description='Bluetooth LE Library'
)
